package com.example.chat.service.websocket;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.example.chat.dao.chat.ChatMapper;
import com.example.chat.entity.chat.Message;
import lombok.extern.slf4j.Slf4j;

import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.swing.*;
import javax.websocket.*;
import javax.websocket.server.ServerEndpoint;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

@Slf4j
@ServerEndpoint(value = "/chat/get")
@Service
public class WebSocketServer {

    private final List<Session> sessionList = new ArrayList<>();

    @Resource
    ChatMapper chatMapper;

    @OnOpen
    public void onOpen(Session session) throws IOException {
        sessionList.add(session);
        log.info("有新用户加入聊天，当前在线人数为{}", sessionList.size());
        List<Message> messageList = chatMapper.getMessage();
        sendAllSession(messageList);
    }

    @OnMessage
    public void onMessage(String message) throws IOException {
        Message message1= JSON.parseObject(message,Message.class);
        chatMapper.addMessage(message1);
        List<Message> messageList=chatMapper.getMessage();
        sendAllSession(messageList);
    }
    @OnError
    public  void onError(Throwable error){
        log.error("发生错误");
        error.printStackTrace();
    }

    @OnClose
    public void onClose(Session session){
        log.info("有一个用户断开连接了");
        sessionList.remove(session);
    }

    /*
     * 发消息给客户端
     * */
    public void sendAllSession(List<Message> message) throws IOException {

        try {
            for (Session session : sessionList) {
                log.info("给客户端发送消息{}",session);
                session.getBasicRemote().sendObject(message);
            }
        } catch (Exception e) {
            log.error("消息发送失败", e);
        }

    }


}
